@@ -46,3 +46,10 @@ impl FromV8 for ByteString {
     Ok(buffer.into())
   }
 }
+
+#[allow(clippy::from_over_into)]
+impl Into<Vec<u8>> for ByteString {
+  fn into(self) -> Vec<u8> {
+    self.0
+  }
+}
