@@ -8,7 +8,9 @@ use crate::error::{Error, Result};
 use crate::keys::v8_struct_key;
 use crate::magic::transl8::MAGIC_FIELD;
 use crate::magic::transl8::{opaque_deref, opaque_recv, MagicType, ToV8};
-use crate::{magic, Buffer, ByteString, DetachedBuffer, U16String};
+use crate::{
+  magic, ByteString, DetachedBuffer, StringOrBuffer, U16String, ZeroCopyBuf,
+};
 
 type JsValue<'s> = v8::Local<'s, v8::Value>;
 type JsResult<'s> = Result<JsValue<'s>>;
@@ -260,10 +262,11 @@ impl<'a, 'b, 'c, T: MagicType + ToV8> ser::SerializeStruct
 // Dispatches between magic and regular struct serializers
 pub enum StructSerializers<'a, 'b, 'c> {
   Magic(MagicalSerializer<'a, 'b, 'c, magic::Value<'a>>),
-  MagicBuffer(MagicalSerializer<'a, 'b, 'c, Buffer>),
+  ZeroCopyBuf(MagicalSerializer<'a, 'b, 'c, ZeroCopyBuf>),
   MagicDetached(MagicalSerializer<'a, 'b, 'c, DetachedBuffer>),
   MagicByteString(MagicalSerializer<'a, 'b, 'c, ByteString>),
   MagicU16String(MagicalSerializer<'a, 'b, 'c, U16String>),
+  MagicStringOrBuffer(MagicalSerializer<'a, 'b, 'c, StringOrBuffer>),
   Regular(ObjectSerializer<'a, 'b, 'c>),
 }
 
@@ -278,10 +281,13 @@ impl<'a, 'b, 'c> ser::SerializeStruct for StructSerializers<'a, 'b, 'c> {
   ) -> Result<()> {
     match self {
       StructSerializers::Magic(s) => s.serialize_field(key, value),
-      StructSerializers::MagicBuffer(s) => s.serialize_field(key, value),
+      StructSerializers::ZeroCopyBuf(s) => s.serialize_field(key, value),
       StructSerializers::MagicDetached(s) => s.serialize_field(key, value),
       StructSerializers::MagicByteString(s) => s.serialize_field(key, value),
       StructSerializers::MagicU16String(s) => s.serialize_field(key, value),
+      StructSerializers::MagicStringOrBuffer(s) => {
+        s.serialize_field(key, value)
+      }
       StructSerializers::Regular(s) => s.serialize_field(key, value),
     }
   }
@@ -289,10 +295,11 @@ impl<'a, 'b, 'c> ser::SerializeStruct for StructSerializers<'a, 'b, 'c> {
   fn end(self) -> JsResult<'a> {
     match self {
       StructSerializers::Magic(s) => s.end(),
-      StructSerializers::MagicBuffer(s) => s.end(),
+      StructSerializers::ZeroCopyBuf(s) => s.end(),
       StructSerializers::MagicDetached(s) => s.end(),
       StructSerializers::MagicByteString(s) => s.end(),
       StructSerializers::MagicU16String(s) => s.end(),
+      StructSerializers::MagicStringOrBuffer(s) => s.end(),
       StructSerializers::Regular(s) => s.end(),
     }
   }
@@ -527,14 +534,18 @@ impl<'a, 'b, 'c> ser::Serializer for Serializer<'a, 'b, 'c> {
         let m = MagicalSerializer::<U16String>::new(self.scope);
         Ok(StructSerializers::MagicU16String(m))
       }
-      Buffer::MAGIC_NAME => {
-        let m = MagicalSerializer::<Buffer>::new(self.scope);
-        Ok(StructSerializers::MagicBuffer(m))
+      ZeroCopyBuf::MAGIC_NAME => {
+        let m = MagicalSerializer::<ZeroCopyBuf>::new(self.scope);
+        Ok(StructSerializers::ZeroCopyBuf(m))
       }
       DetachedBuffer::MAGIC_NAME => {
         let m = MagicalSerializer::<DetachedBuffer>::new(self.scope);
         Ok(StructSerializers::MagicDetached(m))
       }
+      StringOrBuffer::MAGIC_NAME => {
+        let m = MagicalSerializer::<StringOrBuffer>::new(self.scope);
+        Ok(StructSerializers::MagicStringOrBuffer(m))
+      }
       magic::Value::MAGIC_NAME => {
         let m = MagicalSerializer::<magic::Value<'a>>::new(self.scope);
         Ok(StructSerializers::Magic(m))
